package com.baicizhan.client.business.util

import android.app.Application
import android.content.res.Resources
import com.baicizhan.client.framework.handler.AbstractAppHandler
import com.baicizhan.client.framework.log.L
import com.baicizhan.client.framework.util.Common
import com.baicizhan.framework.kv.BczKvMgr
import me.jessyan.autosize.AutoSize
import me.jessyan.autosize.AutoSizeCompat
import me.jessyan.autosize.AutoSizeConfig
import java.lang.Exception
import kotlin.properties.Delegates

object AutoSizeMgr {
    const val TAG = "AutoSizeMgr"
    private const val KEY_CONFIG_AUTO_SIZE = "key_config_auto_size"
    private val useAutoSize by lazy {
        !BczKvMgr.getDefault().getBoolean(KEY_CONFIG_AUTO_SIZE, false)
    }

    var userCloseAutoSize: Boolean by Delegates.observable(BczKvMgr.getDefault().getBoolean(KEY_CONFIG_AUTO_SIZE, false)) { _, _, newValue ->
        BczKvMgr.getDefault().putBoolean(KEY_CONFIG_AUTO_SIZE, newValue)
    }

    fun adjust(res: Resources?) {
        if(!useAutoSize || null == res){
            return
        }
        val h = Common.getScreenHeight(AbstractAppHandler.getApp())
        val w = Common.getScreenWidth(AbstractAppHandler.getApp())
        if (w != 0 && h / w.toFloat() >= 1.3f) {
            try {
                AutoSizeCompat.autoConvertDensityOfGlobal(res);//如果没有自定义需求用这个方法
            } catch (e: Exception) {
                L.e(TAG, "", e)
            }
        }
    }

    fun autoSizeInit(app: Application) {
        if(!useAutoSize){
            return
        }
        val h = Common.getScreenHeight(app)
        val w = Common.getScreenWidth(app)
        if (w != 0 && h / w.toFloat() >= 1.3f) {
            AutoSize.checkAndInit(AbstractAppHandler.getApp())
            AutoSizeConfig.getInstance().isExcludeFontScale = true
            L.i(TAG, "use autoSize, %d, %d", h, w)
        }
    }

}