package com.baicizhan.client.business.view

import android.os.SystemClock
import android.util.Log
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import com.baicizhan.client.business.BuildConfig
import com.baicizhan.client.business.view.OnProtectedClickListener.PROTECTED_DELAY

/**
 * Created by Jacee.
 * Date: 2020.04.07
 */

private const val TAG = "view_ext"

fun View.setOnProtectedClickListener(delay: Int = PROTECTED_DELAY, l: (View) -> Unit) {
    var time: Long = 0
    setOnClickListener {
        val cur = SystemClock.elapsedRealtime()
        if (BuildConfig.DEBUG) Log.d(TAG, "time = $time, cur = $cur, ${time + delay < cur}")
        if (time == 0L || time + delay < cur) {
            l(it)
            time = cur
        }
    }
}

fun View.setOnProtectedClickListener(l: View.OnClickListener, delay: Int = PROTECTED_DELAY) {
    var time: Long = 0
    setOnClickListener {
        val cur = SystemClock.elapsedRealtime()
        if (BuildConfig.DEBUG) Log.d(TAG, "time = $time, cur = $cur, ${time + delay < cur}")
        if (time == 0L || time + delay < cur) {
            l.onClick(it)
            time = cur
        }
    }
}

fun Array<out View>.setOnProtectedClickListener(delay: Int = PROTECTED_DELAY, l: (View) -> Unit) {
    forEach {
        it.setOnProtectedClickListener(delay) { v -> l(v) }
    }
}

var View.visible: Boolean
    get() = visibility == View.VISIBLE
    set(value) {
        visibility = if (value) View.VISIBLE else View.GONE
    }

var TextView.content: CharSequence?
    get() = text
    set(value) {
        text = value
        visible = !value.isNullOrEmpty()
    }

fun ViewGroup.forEach(recursive: Boolean, block: (View) -> Unit) {
    var child: View
    for (i in 0 until childCount) {
        child = getChildAt(i)
        block(child)
        if (recursive && child is ViewGroup) {
            child.forEach(recursive, block)
        }
    }
}